import type { ActionCreator, Reducer } from 'redux';
import type { ThunkAction } from 'redux-thunk';
import type { RootState } from '.';
import type { Item } from './aggregations-queries-items';
export declare type Status = 'initial' | 'fetching' | 'error' | 'ready';
export declare type State = {
    isModalOpen: boolean;
    selectedItem: Item | null;
    createCollectionStatus: Status;
    databases: string[];
    selectedDatabase: string | null;
    databasesStatus: Status;
    collections: string[];
    selectedCollection: string | null;
    collectionsStatus: Status;
};
export declare enum ActionTypes {
    OpenModal = "compass-saved-aggregations-queries/openModal",
    CloseModal = "compass-saved-aggregations-queries/closeModal",
    CreateNamespaceStatusChange = "compass-saved-aggregations-queries/createNamespaceStatusChange",
    SelectDatabase = "compass-saved-aggregations-queries/selectDatabase",
    LoadDatabases = "compass-saved-aggregations-queries/loadDatabases",
    LoadDatabasesSuccess = "compass-saved-aggregations-queries/loadDatabasesSuccess",
    LoadDatabasesError = "compass-saved-aggregations-queries/loadDatabasesError",
    SelectCollection = "compass-saved-aggregations-queries/selectCollection",
    LoadCollections = "compass-saved-aggregations-queries/loadCollections",
    LoadCollectionsSuccess = "compass-saved-aggregations-queries/loadCollectionsSuccess",
    LoadCollectionsError = "compass-saved-aggregations-queries/loadCollectionsError"
}
declare type OpenModalAction = {
    type: ActionTypes.OpenModal;
    selectedItem: Item;
};
declare type CloseModalAction = {
    type: ActionTypes.CloseModal;
};
declare type CreateNamespaceStatusChangeAction = {
    type: ActionTypes.CreateNamespaceStatusChange;
    status: Status;
};
declare type SelectDatabaseAction = {
    type: ActionTypes.SelectDatabase;
    database: string;
};
declare type LoadDatabasesAction = {
    type: ActionTypes.LoadDatabases;
};
declare type LoadDatabasesSuccessAction = {
    type: ActionTypes.LoadDatabasesSuccess;
    databases: string[];
};
declare type LoadDatabasesErrorAction = {
    type: ActionTypes.LoadDatabasesError;
};
declare type SelectCollectionAction = {
    type: ActionTypes.SelectCollection;
    collection: string;
};
declare type LoadCollectionsAction = {
    type: ActionTypes.LoadCollections;
};
declare type LoadCollectionsSuccessAction = {
    type: ActionTypes.LoadCollectionsSuccess;
    collections: string[];
};
declare type LoadCollectionsErrorAction = {
    type: ActionTypes.LoadCollectionsError;
};
export declare type Actions = OpenModalAction | CloseModalAction | CreateNamespaceStatusChangeAction | SelectDatabaseAction | LoadDatabasesAction | LoadDatabasesErrorAction | LoadDatabasesSuccessAction | SelectCollectionAction | LoadCollectionsAction | LoadCollectionsErrorAction | LoadCollectionsSuccessAction;
declare const reducer: Reducer<State, Actions>;
export declare const closeModal: ActionCreator<CloseModalAction>;
export declare const openSavedItem: (id: string) => ThunkAction<void, RootState, void, Actions>;
export declare const openSelectedItem: () => ThunkAction<void, RootState, void, Actions>;
export declare const selectDatabase: (database: string) => ThunkAction<void, RootState, void, Actions>;
export declare const selectCollection: ActionCreator<SelectCollectionAction>;
export default reducer;
//# sourceMappingURL=open-item.d.ts.map